;; Generated package description from ada-mode.el  -*- no-byte-compile: t -*-
(define-package "ada-mode" "7.3.0.0.20221022.100212" "major-mode for editing Ada sources" '((uniquify-files "1.0.1") (wisi "4.0.0") (emacs "25.3")) :commit "11a6a5a1da7048c440e17f185652d9ba283f8cf7" :authors '(("Stephen Leake" . "stephen_leake@stephe-leake.org")) :maintainer '("Stephen Leake" . "stephen_leake@stephe-leake.org") :keywords '("languages" "ada") :url "http://www.nongnu.org/ada-mode/")
